Range-v3: ranges::v3::all_of_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::all_of_fn Struct Reference
Algorithms

## Public Member Functions
template<typename I , typename S , typename F , typename P = ident, requires = (InputIterator<I>() && Sentinel<S, I>() && IndirectPredicate<F, projected<I, P> >())>
bool | operator() (I first, S last, F pred, P proj=P{}) const
template<typename Rng , typename F , typename P = ident, typename I = iterator_t<Rng>, requires = (InputRange<Rng>() && IndirectPredicate<F, projected<I, P> >())>
bool | operator() (Rng &&rng, F pred, P proj=P{}) const